#
# spec file for package libzrtpcpp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libzrtpcpp
%define lname	libzrtpcpp4
Version:        4.7.0
Release:        2.2
Summary:        A ccrtp extension for ZRTP support
License:        GPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            http://www.gnutelephony.org/index.php/GNU_ZRTP
#Git-Clone:	git://github.com/wernerd/ZRTPCPP
#Git-Web:	https://github.com/wernerd/ZRTPCPP
Source:         https://github.com/wernerd/ZRTPCPP/archive/%version.tar.gz
Patch0:         libzrtpcpp-openssl3.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++ >= 4.7
BuildRequires:  libopenssl-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libccrtp) >= 2
BuildRequires:  pkgconfig(sqlite3) >= 3.7

%description
A library that adds RFC6189-compliant ZRTP support to the GNU ccRTP
stack and serves as library for other RTP stacks such as PJSIP and
GStreamer. ZRTP was developed to allow ad-hoc key negotiation to
setup Secure RTP (SRTP) sessions.

%package -n %lname
Summary:        A ccrtp extension for ZRTP support
Group:          System/Libraries

%description -n %lname
A library that adds RFC6189-compliant ZRTP support to the GNU ccRTP
stack and serves as library for other RTP stacks such as PJSIP and
GStreamer. ZRTP was developed to allow ad-hoc key negotiation to
setup Secure RTP (SRTP) sessions.

%package devel
Summary:        Headers and link library for libzrtpcpp
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       ccrtp-devel >= 2.0.0

%description devel
This package provides the header files for building applications that
use libzrtpcpp.

%prep
%autosetup -p1 -n ZRTPCPP-%version
chmod a-x INSTALL

%build
# libzrtpcpp changed its API (apparently - can't tell whether aes_init
# was meant to be exported or not), but failed to bump the SO version.
# So now, add explicit symbol versions to ensure programs with wrong
# ABI combinations are caught.
echo "V_%version { global: *; };" >version.map
%cmake -DCMAKE_INSTALL_PREFIX="%_prefix" \
	-DCMAKE_C_FLAGS:STRING="%optflags" \
	-DCMAKE_CXX_FLAGS:STRING="%optflags" \
	-DCMAKE_LD_FLAGS:STRING="-Wl,--version-script=$PWD/version.map" \
	-DCRYPTO_STANDALONE:BOOL=false \
%if "%_lib" == "lib64"
	-DLIB_SUFFIX=64 \
%endif

%cmake_build

%install
%cmake_install

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPYING
%_libdir/libzrtpcpp.so.4*

%files devel
%doc AUTHORS README.md
%_libdir/libzrtpcpp.so
%_libdir/pkgconfig/libzrtpcpp.pc
%_includedir/libzrtpcpp/

%changelog
* Tue Oct 22 2024 Pedro Monreal <pmonreal@suse.com>
- Adapt libzrtpcpp to build with OpenSSL 3 [bsc#1219884]
  * Add libzrtpcpp-openssl3.patch
* Sun Sep  6 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.7.0
  * Add a first version of a new SAS algorithm which renders 6 digits
* Sun Dec 10 2017 jengelh@inai.de
- BuildRequire pre-1.1 openssl.
* Mon Jul 31 2017 jengelh@inai.de
- Update to new maintenance release 4.6.6
  * Fix a memory leak, extra buffer length checks added.
- Remove typo.diff (merged)
* Mon Nov 21 2016 jengelh@inai.de
- Update to new upstream release 4.6.4
  * Include the openSSL specific hmac.h file when building SRTP
    with openSSL crypto backend.
  * Rename macro "DEPRECATED" to "DEPRECATED_ZRTP" to avoid
    name clashes.
  * Add warning code to ZrtpCWrapper.h if AuxSecret match fails.
- Add typo.diff to make it build
* Wed Mar 23 2016 jengelh@inai.de
- Update to new upstream release 4.6.3
  * A small fix inside the ZRTP main module to ignore malformed
  DH1 packets and avoid an NULL pointer access.
* Mon Feb  8 2016 jengelh@inai.de
- Update to new upstream release 4.6.2
  * add-on to the code to implement handling of the disclosure flag.
  See RFC6189, chapter 11 for more details.
  * A fix in the ZrtpCWrapper to initialize and use the ZRTP
  master instance in case of multi-stream usage.
* Fri Jan 22 2016 jengelh@inai.de
- Update to new upstream release 4.5.0
  * Added a new SAS algorithm 'B32E' that uses 32 Unicode Emoji
  code points instead of 32 ASCII characters. Application that
  are able to display Emojis may use this new SAS algorithm to
  display nice Emojis instead of 'boring' ASCII letters and
  digits.
- Drop unused keyring file from SRPM
* Fri Aug 14 2015 jengelh@inai.de
- Update to new upstream release 4.4.0
  * Changes to the handling of HMAC and Hash contexts to avoild too
  many malloc/free calls and thus memory pointer problems.
  * Enhance the handling an check the nonce when using multi-stream
  mode.
- Drop 0001-pkg-config-add-includedir-libzrtcpp-to-CFLAGS.patch
  (merged)
* Tue Mar 17 2015 jengelh@inai.de
- Update to new upstream release 4.3.1
  * This version adds some new API that provide to set retry timer
  values and to get some retry counters.
  * Application may now set some values of the retry counters during
  the discovery (Hello) and the negotiation phase. Applications may
  increase the number of retries or modify the capping to support
  slow or bad networks.
* Sat Oct 25 2014 jengelh@inai.de
- Add 0001-pkg-config-add-includedir-libzrtcpp-to-CFLAGS.patch
  to fix downstream compilation [bso#902614]
* Mon Oct 13 2014 jengelh@inai.de
- Set version on BuildRequire dependency; the project needs a C++11
  compiler.
* Sat Sep  6 2014 jengelh@inai.de
- Update to new upstream release 4.2.4
  * Rename functions aes_init() to aes_init_zrtp() to avoid names
  clashes with other libreries that may include own AES modules.
* Sat Jun 28 2014 jengelh@inai.de
- Update to new upstream release 4.2.3
  * Enhance SRTP handling to provide a longer bit-shift register
  * Add functions to read ZID cache entries, raw data, formatted
  as string
  * Order full ZID list by secure-since date
* Sun Nov 24 2013 jengelh@inai.de
- Update to new upstream release 4.1.0
  * added some new algorithms for the DH key agreement and the Skein
  Hash for ZRTP.
* Wed Jul  3 2013 jengelh@inai.de
- Update to new upstream release 3.2.2.2
  * Re-structure ZRTP cache and add SQlite3 as optional storage backend
  * Fixes CVE-2013-2221 CVE-2013-2222 CVE-2013-2223 (bnc#828028)
* Thu Jun 13 2013 jengelh@inai.de
- Update to new upstream release 2.3.3
  * Fallback to libgcrypt if openssl has no Elliptical Curve
  support (no user-visible changes)
* Wed Jun  5 2013 jengelh@inai.de
- Update to new upstream release 2.3.2
  * Upstream has not provided a NEWS/changelog entry
- Do signature verification
- Remove redundant %%clean section; more robust make install call
- Remove libzrtpcpp-libdir.patch (no longer required)
* Sat Mar 23 2013 schwab@suse.de
- Properly determine LIB_SUFFIX
* Thu Apr  5 2012 dvaleev@suse.com
- better libdir handling
* Thu Apr  5 2012 dvaleev@suse.com
- fix libdir for ppc64
* Tue Sep 27 2011 coolo@suse.com
- fix the shared library policy packaging
* Sat Aug 20 2011 Werner.Dittmann@t-online.de
- Modify and rename spec file to adhere to naming policies
  * remove rpmlintrc file - not longer used
* Mon Aug  1 2011 Werner.Dittmann@t-online.de
- update to version 2.0 to be in sync with version number of GNU ccRTP
  * Update configuration to use the new GNU uCommon library
* Sat Jan  8 2011 Werner.Dittmann@t-online.de
- Update to latest version of GNU ZRTP C++
  * Cumulative update that implements all fixes and
    versions since 1.3.0 (see below)
  * Protocol implementation compliant with latest ZRTP
    specification.
  * lots of documentation added (doxygen ready)
  * some code cleanup
* Thu Dec  9 2010 rguenther@novell.com
- drop bogus libgcc BuildRequires
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Mon Sep  8 2008 hvogel@suse.de
- Update to 1.3.0
  * implements the latest changes define in the ZRTP draft
  * The Method ''setSipsSecret(...)'' is no longer available.
  * The method ''setOtherSecret(...)'' was renamed to
    ''setPbxSecret(...)''
  * The methos ''setSrtpsSecret(...)'' is was renamed to
    ''setAuxSecret(...)''
* Sun May 11 2008 crrodriguez@suse.de
- fix  no-return-in-nonvoid-function errors
- fix both buildRequires and -devel package dependencies
- remove static libraries and "la" files
* Wed Apr  2 2008 hvogel@suse.de
- update to version 1.0.1
  * various bugfixes
- add libzrtpcpp1 sub-package
* Tue Mar 27 2007 mskibbe@suse.de
- fix compiler warnings
- fix changlog date problems
* Fri Mar  2 2007 mskibbe@suse.de
- libzrtpcpp-devel has a broken epoch and packaging bugs (#249532)
* Thu Feb 15 2007 mskibbe@suse.de
- change package for SuSE
* Sun Oct 15 2006 cs@linux-administrator.com
- initial package build for SuSE 10.1
